Regression benchmarks
---

[![Build Status](https://travis-ci.org/Ohjeah/regression-benchmarks.svg?branch=master)](https://travis-ci.org/Ohjeah/regression-benchmarks) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
